@@ -27,11 +27,11 @@ class EigenValuesAssistant : public Cantor::Assistant
 {
   public:
     EigenValuesAssistant( QObject* parent, QList<QVariant> args );
-    ~EigenValuesAssistant();
+    ~EigenValuesAssistant() override;
 
-    void initActions();
+    void initActions() Q_DECL_OVERRIDE;
     
-    QStringList run(QWidget* parentt);
+    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
     
 };
 
