@@ -102,10 +102,14 @@ void RExpression::showFilesAsResult(const QStringList& files)
         {
             qDebug()<<"its PostScript";
             setResult(new Cantor::EpsResult(QUrl::fromLocalFile(file)));
-        } else if(type.inherits(QLatin1String("text/plain")))
+        }
+        else if(type.inherits(QLatin1String("text/plain")) 
+            || type.inherits(QLatin1String("application/x-extension-html")))
         {
             //Htmls are also plain texts, combining this in one
-            if(type.inherits(QLatin1String("text/html")))
+            const bool isHtml = type.inherits(QLatin1String("text/html"))
+                || type.inherits(QLatin1String("application/x-extension-html"));
+            if(isHtml)
                 qDebug()<<"its a HTML document";
             else
                 qDebug()<<"its plain text";
@@ -118,15 +122,16 @@ void RExpression::showFilesAsResult(const QStringList& files)
                 setStatus(Cantor::Expression::Error);
             }
             QString content=QTextStream(&f).readAll();
-            if (!type.inherits(QLatin1String("text/html")))
+            if (!isHtml)
             {
                 //Escape whitespace
                 content.replace( QLatin1Char(' '), QLatin1String("&nbsp;"));
                 //replace appearing backspaces, as they mess the whole output up
                 content.remove(QRegExp(QLatin1String(".\b")));
-                //Replace < and > with their html code, so they won't be confused as html tags
+                //Replace <, > and & with their html code, so they won't be confused as html tags
                 content.replace( QLatin1Char('<') ,  QLatin1String("&lt;"));
                 content.replace( QLatin1Char('>') ,  QLatin1String("&gt;"));
+                content.replace( QLatin1Char('&') ,  QLatin1String("&amp;"));
             }
 
             qDebug()<<"content: "<<content;
@@ -142,9 +147,16 @@ void RExpression::showFilesAsResult(const QStringList& files)
         }
         else
         {
-            setResult(new Cantor::TextResult(i18n("cannot open file %1: Unknown MimeType", file)));
-            setErrorMessage(i18n("cannot open file %1: Unknown MimeType", file));
-            setStatus(Cantor::Expression::Error);
+            // File has unsupported mime type, but we suspect, that it is text, so will open the file in Cantor script editor
+            // Even if it don't text, the script editor can deals with it.
+            setResult(new Cantor::TextResult(QLatin1String("")));
+            setStatus(Cantor::Expression::Done);
+            const QString& editor = QStandardPaths::findExecutable(QLatin1String("cantor_scripteditor"));
+            int code = QProcess::execute(editor, QStringList(file));
+            if (code == -2)
+                qDebug() << "failed to open the file " << file << " with the script editor '" << editor << "'";
+            else if (code == -1)
+                qDebug() << "Cantor script editor crashed";
         }
     }
 }
