@@ -84,9 +84,9 @@ RServer::RServer() : m_isInitialized(false),m_isCompletionAvailable(false)
 {
     new RAdaptor(this);
 
+    m_tmpDir = QDir::tempPath() + QString::fromLatin1("/cantor_rserver-%1").arg(getpid());
     QDir dir;
-    dir.mkdir(QDir::tempPath() + QString::fromLatin1("/cantor/rserver-%1").arg(getpid()));
-    m_tmpDir=QDir::tempPath() + QString::fromLatin1("/cantor/rserver-%1").arg(getpid());
+    dir.mkdir(m_tmpDir);
     qDebug()<<"storing plots at "<<m_tmpDir;
 
     initR();
@@ -127,6 +127,9 @@ void RServer::initR()
 
     autoload();
 
+    // Set gui editor for R
+    runCommand(QLatin1String("options(editor = 'cantor_scripteditor') \n"),true);
+
     //Setting up some settings dependent stuff
     if(RServerSettings::self()->integratePlots())
     {
@@ -355,7 +358,9 @@ void RServer::runCommand(const QString& cmd, bool internal)
         {
             qDebug()<<"printing result...";
             SEXP count=PROTECT(R_tryEval(lang2(install("length"),result),NULL,&errorOccurred)); // TODO: error checks
-            if (*INTEGER(count)==1)
+            if (*INTEGER(count)==0)
+                qDebug() << "no result, so show nothing";
+            else if (*INTEGER(count)==1)
                 Rf_PrintValue(result);
             else
             {
