@@ -26,17 +26,18 @@ class OctaveBackend : public Cantor::Backend
 {
     Q_OBJECT
     public:
-    explicit OctaveBackend( QObject* parent = 0,const QList<QVariant> args = QList<QVariant>());
-     ~OctaveBackend();
-    virtual QString id() const;
-    virtual Cantor::Backend::Capabilities capabilities() const;
-    virtual Cantor::Session* createSession();
+    explicit OctaveBackend( QObject* parent = nullptr,const QList<QVariant> args = QList<QVariant>());
+     ~OctaveBackend() override;
+    QString id() const Q_DECL_OVERRIDE;
+    QString version() const override;
+    Cantor::Backend::Capabilities capabilities() const Q_DECL_OVERRIDE;
+    Cantor::Session* createSession() Q_DECL_OVERRIDE;
 
-    virtual bool requirementsFullfilled() const;
-    virtual QUrl helpUrl() const;
-    virtual QString description() const;
-    virtual QWidget* settingsWidget(QWidget* parent) const;
-    virtual KConfigSkeleton* config() const;
+    bool requirementsFullfilled() const Q_DECL_OVERRIDE;
+    QUrl helpUrl() const Q_DECL_OVERRIDE;
+    QString description() const Q_DECL_OVERRIDE;
+    QWidget* settingsWidget(QWidget* parent) const Q_DECL_OVERRIDE;
+    KConfigSkeleton* config() const Q_DECL_OVERRIDE;
 };
 
 #endif
