@@ -28,7 +28,7 @@
 OctaveCompletionObject::OctaveCompletionObject(const QString& command, int index, Cantor::Session* parent): CompletionObject(parent)
 {
     setLine(command, index);
-    m_expression = 0;
+    m_expression = nullptr;
 }
 
 OctaveCompletionObject::~OctaveCompletionObject()
@@ -41,7 +41,7 @@ void OctaveCompletionObject::fetchCompletions()
     if (m_expression)
 	return;
     qDebug() << "Fetching completions for" << command();
-    QString expr = QString::fromLatin1("completion_matches(\"%1\")").arg(command());
+    QString expr = QString::fromLatin1("completion_matches('%1')").arg(command());
     m_expression = session()->evaluateExpression(expr);
     connect(m_expression, &Cantor::Expression::statusChanged, this, &OctaveCompletionObject::extractCompletions);
 }
@@ -53,7 +53,7 @@ void OctaveCompletionObject::extractCompletions()
     if (m_expression->status() != Cantor::Expression::Done)
     {
 	m_expression->deleteLater();
-	m_expression = 0;
+	m_expression = nullptr;
         return;
     }
     Cantor::Result* result = m_expression->result();
@@ -65,7 +65,7 @@ void OctaveCompletionObject::extractCompletions()
         setCompletions( completions );
     }
     m_expression->deleteLater();
-    m_expression = 0;
+    m_expression = nullptr;
     emit fetchingDone();
 }
 
@@ -77,8 +77,7 @@ void OctaveCompletionObject::fetchIdentifierType()
     // The output should look like
     // sin is a built-in function
     // __cantor_tmp2__ = 5
-    QString expr = QString::fromLatin1("__cantor_internal1__ = ans; type(\"%1\"); __cantor_internal2__ = ans; ans = __cantor_internal1__; __cantor_internal2__")
-                                      .arg(identifier());
+    QString expr = QString::fromLatin1("ans = type('%1');ans").arg(identifier());
     m_expression = session()->evaluateExpression(expr);
     connect(m_expression, &Cantor::Expression::statusChanged, this, &OctaveCompletionObject::extractIdentifierType);
 }
@@ -91,12 +90,12 @@ void OctaveCompletionObject::extractIdentifierType()
     if (m_expression->status() != Cantor::Expression::Done)
     {
 	m_expression->deleteLater();
-	m_expression = 0;
+	m_expression = nullptr;
         return;
     }
     Cantor::Result* result = m_expression->result();
     m_expression->deleteLater();
-    m_expression = 0;
+    m_expression = nullptr;
     if (!result)
 	return;
 
