@@ -30,7 +30,7 @@ namespace Cantor {
 
 class ScilabExpression;
 class KDirWatch;
-class KProcess;
+class QProcess;
 
 class ScilabSession : public Cantor::Session
 {
@@ -38,7 +38,7 @@ class ScilabSession : public Cantor::Session
 
     public:
         ScilabSession(Cantor::Backend* backend);
-        ~ScilabSession();
+        ~ScilabSession() override;
 
         void login() Q_DECL_OVERRIDE;
         void logout() Q_DECL_OVERRIDE;
@@ -62,7 +62,7 @@ class ScilabSession : public Cantor::Session
         void updateVariableHighlighter();
 
     private:
-        KProcess* m_process;
+        QProcess* m_process;
         KDirWatch* m_watch;
         QStringList m_listPlotName;
         QString m_output;
