@@ -42,15 +42,14 @@ namespace Cantor
  */
 class CANTOR_EXPORT Extension : public QObject
 {
+  Q_OBJECT
   public:
     ///Default constructor
     Extension( const QString& name, QObject* parent );
-    ~Extension();
-
+    ~Extension() override;
 };
 
 
-
 //Some basic interfaces for extensions
 
 /**
@@ -58,9 +57,10 @@ class CANTOR_EXPORT Extension : public QObject
  */
 class CANTOR_EXPORT HistoryExtension : public Extension
 {
+  Q_OBJECT
   public:
     HistoryExtension(QObject* parent);
-    ~HistoryExtension();
+    ~HistoryExtension() override;
   public Q_SLOTS:
     /**
      * Returns a command that retrieves the last result
@@ -75,9 +75,10 @@ class CANTOR_EXPORT HistoryExtension : public Extension
  */
 class CANTOR_EXPORT ScriptExtension : public Extension
 {
+  Q_OBJECT
   public:
     ScriptExtension(QObject* parent);
-    ~ScriptExtension();
+    ~ScriptExtension() override;
   public Q_SLOTS:
     /**
      * returns the command for running a script
@@ -121,9 +122,10 @@ class CANTOR_EXPORT ScriptExtension : public Extension
 **/
 class CANTOR_EXPORT CASExtension : public Extension
 {
+  Q_OBJECT
   public:
     CASExtension(QObject* parent);
-    ~CASExtension();
+    ~CASExtension() override;
 
   public Q_SLOTS:
     /**
@@ -153,9 +155,10 @@ class CANTOR_EXPORT CASExtension : public Extension
  */
 class CANTOR_EXPORT CalculusExtension : public Extension
 {
+  Q_OBJECT
   public:
     CalculusExtension(QObject* parent);
-    ~CalculusExtension();
+    ~CalculusExtension() override;
 
   public Q_SLOTS:
     /**
@@ -197,12 +200,13 @@ class CANTOR_EXPORT CalculusExtension : public Extension
  */
 class CANTOR_EXPORT PlotExtension : public Extension
 {
+  Q_OBJECT
   public:
     typedef QPair<QString,QString> Interval;
     typedef QPair<QString, Interval> VariableParameter;
 
     PlotExtension(QObject* parent);
-    ~PlotExtension();
+    ~PlotExtension() override;
 
   public Q_SLOTS:
     /**
@@ -238,9 +242,10 @@ class CANTOR_EXPORT PlotExtension : public Extension
  */
 class CANTOR_EXPORT AdvancedPlotExtension : public Extension
 {
+  Q_OBJECT
   public:
     AdvancedPlotExtension(QObject* parent);
-    ~AdvancedPlotExtension();
+    ~AdvancedPlotExtension() override;
 
     // TODO comment
 
@@ -370,12 +375,13 @@ template <class Directive> AdvancedPlotExtension::DirectiveAcceptor<Directive>::
  */
 class CANTOR_EXPORT LinearAlgebraExtension : public Extension
 {
+  Q_OBJECT
   public:
     enum VectorType { ColumnVector, RowVector };
     typedef QList<QStringList> Matrix;
 
     LinearAlgebraExtension(QObject* parent);
-    ~LinearAlgebraExtension();
+    ~LinearAlgebraExtension() override;
 
   public Q_SLOTS:
     //Commands to create Vectors/Matrices
@@ -449,9 +455,10 @@ class CANTOR_EXPORT LinearAlgebraExtension : public Extension
 
 class CANTOR_EXPORT VariableManagementExtension : public Extension
 {
+  Q_OBJECT
   public:
     VariableManagementExtension( QObject* parent );
-    ~VariableManagementExtension();
+    ~VariableManagementExtension() override;
 
   public Q_SLOTS:
     virtual QString addVariable(const QString& name, const QString& value) = 0;
@@ -468,9 +475,10 @@ class CANTOR_EXPORT VariableManagementExtension : public Extension
  */
 class CANTOR_EXPORT PackagingExtension : public Extension
 {
+  Q_OBJECT
   public:
     PackagingExtension(QObject* parent);
-    ~PackagingExtension();
+    ~PackagingExtension() override;
 
   public Q_SLOTS:
     /**
