@@ -27,7 +27,7 @@ class PlaceHolderEntry : public WorksheetEntry
 {
   public:
     PlaceHolderEntry(Worksheet* worksheet, QSizeF s);
-    ~PlaceHolderEntry();
+    ~PlaceHolderEntry() override;
 
     enum {Type = UserType + 6};
     int type() const Q_DECL_OVERRIDE;
